@@ -6,16 +6,14 @@ use API::MikroTik::Sentence qw(encode_sentence);
 use Carp ();
 use Mojo::Collection;
 use Mojo::IOLoop;
-use Mojo::Util qw(md5_sum deprecated);
+use Mojo::Util 'md5_sum';
 use Scalar::Util 'weaken';
 
 use constant CONN_TIMEOUT => $ENV{API_MIKROTIK_CONNTIMEOUT};
 use constant DEBUG        => $ENV{API_MIKROTIK_DEBUG} || 0;
 use constant PROMISES     => !!(eval { require Mojo::Promise; 1 });
 
-our $VERSION = '0.24.1';
-
-deprecated "This module is deprecated in favour of MikroTik::Client";
+our $VERSION = '0.23';
 
 has error    => '';
 has host     => '192.168.88.1';
@@ -262,7 +260,7 @@ sub _write_sentence {
 
 =head1 NAME
 
-API::MikroTik - Non-blocking interface to MikroTik API
+API::MikroTik - Non-blocking interface to MikroTik API.
 
 =head1 SYNOPSIS
 
@@ -291,7 +289,7 @@ API::MikroTik - Non-blocking interface to MikroTik API
   # Subscribe
   $tag = $api->subscribe(
       '/interface/listen' => sub {
-          my ($api, $err, $el) = @_;
+          my ($api, $err, $err) = @_;
           ...;
       }
   );
@@ -321,9 +319,7 @@ API::MikroTik - Non-blocking interface to MikroTik API
 
 =head1 DESCRIPTION
 
-B<This module is deprecated in favour of> L<MikroTik::Client>B<.>
-
-Both blocking and non-blocking interface to a MikroTik API service. With queries,
+Both blocking and non-blocking interface to MikroTik API service. With queries,
 command subscriptions and Promises/A+ (courtesy of an I/O loop). Based on
 L<Mojo::IOLoop> and would work alongside L<EV>.
 
@@ -402,7 +398,7 @@ User name for authentication purposes. Defaults to C<admin>.
   # or with callback
   $api->cancel($tag => sub {...});
 
-Cancels background commands. Can accept a callback as last argument.
+Cancel background commands. Can accept callback as last argument.
 
 =head2 cmd
 
@@ -446,13 +442,13 @@ An alias for L</command_p>.
       die "Error: $err, category: " . $list->[0]{category};
   }
 
-Executes a command on a remote host and returns L<Mojo::Collection> with hashrefs
-containing elements returned by a host. You can append a callback for non-blocking
+Execute a command on a remote host and returns L<Mojo::Collection> with hashrefs
+containing elements returned by host. You can append callback for non-blocking
 calls.
 
 In a case of error it may return extra attributes to C<!trap> or C<!fatal> API
 replies in addition to error messages in an L</error> attribute or an C<$err>
-argument. You should never rely on defines of the result to catch errors.
+argument. You should never rely on defines of result to catch errors.
 
 For a query syntax refer to L<API::MikroTik::Query>.
 
@@ -480,18 +476,18 @@ required for promises functionality.
       });
 
   Mojo::IOLoop->timer(
-      3 => sub { $api->cancel($tag) }
+      3 => sub { $a->cancel($tag) }
   );
 
-Subscribe to an output of commands with continuous responses such as C<listen> or
+Subscribe to an output of command with continuous responses such as C<listen> or
 C<ping>. Should be terminated with L</cancel>.
 
 =head1 DEBUGGING
 
-You can set the API_MIKROTIK_DEBUG environment variable to get some debug output
+You can set API_MIKROTIK_DEBUG environment variable to get some debug output
 printed to stderr.
 
-Also, you can change connection timeout with the API_MIKROTIK_CONNTIMEOUT variable.
+Also, you can change connection timeout with API_MIKROTIK_CONNTIMEOUT variable.
 
 =head1 COPYRIGHT AND LICENSE
 
